<TS version="2.1" language="mn">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation type="unfinished">Шинэ хаяг нээх</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation type="unfinished">&amp;Шинэ</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation type="unfinished">Одоогоор сонгогдсон байгаа хаягуудыг сануулах</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation type="unfinished">&amp;Хуулах</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation type="unfinished">&amp;Хаах</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation type="unfinished">Одоо сонгогдсон байгаа хаягуудыг жагсаалтаас устгах</translation>
    </message>
    <message>
        <source>Enter address or label to search</source>
        <translation type="unfinished">Хайлт хийхийн тулд хаяг эсвэл шошгыг оруул</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation type="unfinished">Сонгогдсон таб дээрхи дата-г экспортлох</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation type="unfinished">&amp;Экспорт</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation type="unfinished">&amp;Устгах</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation type="unfinished">Зооснуудыг илгээх хаягийг сонгоно уу</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation type="unfinished">Зооснуудыг хүлээн авах хаягийг сонгоно уу</translation>
    </message>
    <message>
        <source>C&amp;hoose</source>
        <translation type="unfinished">С&amp;онго</translation>
    </message>
    <message>
        <source>Sending addresses</source>
        <translation type="unfinished">Илгээх хаягууд</translation>
    </message>
    <message>
        <source>Receiving addresses</source>
        <translation type="unfinished">Хүлээн авах хаяг</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
        <translation type="unfinished">Эдгээр Биткойн хаягууд нь илгээх хаягууд. Хүлээн авах хаяг болон тоо хэмжээг илгээхээсээ өмнө сайн нягталж үзэж байна уу</translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation type="unfinished">Хаягийг &amp;Хуулбарлах</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation type="unfinished">&amp;Шошгыг хуулбарлах</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation type="unfinished">&amp;Ѳѳрчлѳх</translation>
    </message>
    <message>
        <source>Export Address List</source>
        <translation type="unfinished">Экспорт хийх хаягуудын жагсаалт</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation type="unfinished">Экспорт амжилтгүй боллоо</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation type="unfinished">Шошго</translation>
    </message>
    <message>
        <source>Address</source>
        <translation type="unfinished">Хаяг</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(шошгогүй)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Enter passphrase</source>
        <translation type="unfinished">Нууц үгийг оруул</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation type="unfinished">Шинэ нууц үг</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation type="unfinished">Шинэ нууц үгийг давтана уу</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation type="unfinished">Түрүйвчийг цоожлох</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation type="unfinished">Энэ үйлдэлийг гүйцэтгэхийн тулд та нууц үгээрээ түрүйвчийн цоожийг тайлах хэрэгтэй</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation type="unfinished">Түрүйвчийн цоожийг тайлах</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation type="unfinished">Нууц үгийг солих</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation type="unfinished">Түрүйвчийн цоожийг баталгаажуулах</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation type="unfinished">Түрүйвч цоожлогдлоо</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation type="unfinished">Түрүйвчийн цоожлол амжилттай болсонгүй</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation type="unfinished">Түрүйвчийн цоожлол дотоод алдаанаас үүдэн амжилттай болсонгүй. Түрүйвч цоожлогдоогүй байна.</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation type="unfinished">Таны оруулсан нууц үг таарсангүй</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation type="unfinished">Түрүйвчийн цоож тайлагдсангүй</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation type="unfinished">Таны оруулсан түрүйвчийн цоожийг тайлах нууц үг буруу байна</translation>
    </message>
    <message>
        <source>Wallet passphrase was successfully changed.</source>
        <translation type="unfinished">Түрүйвчийн нууц үг амжилттай ѳѳр</translation>
    </message>
    </context>
<context>
    <name>BitcoinApplication</name>
    <message>
        <source>Internal error</source>
        <translation type="unfinished">Дотоод алдаа</translation>
    </message>
    </context>
<context>
    <name>QObject</name>
    <message>
        <source>Error: %1</source>
        <translation type="unfinished">Алдаа: %1</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation type="unfinished">үл мэдэгдэх</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation type="unfinished">Хэмжээ</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation type="unfinished">Алга Байна</translation>
    </message>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>&amp;Transactions</source>
        <translation type="unfinished">Гүйлгээнүүд</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation type="unfinished">Гүйлгээнүүдийн түүхийг харах</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation type="unfinished">Гарах</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation type="unfinished">Програмаас Гарах</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation type="unfinished">&amp;Клиентийн тухай</translation>
    </message>
    <message>
        <source>Show information about Qt</source>
        <translation type="unfinished">Клиентийн тухай мэдээллийг харуул</translation>
    </message>
    <message>
        <source>Create a new wallet</source>
        <translation type="unfinished">Шинэ түрийвч үүсгэх</translation>
    </message>
    <message>
        <source>Wallet:</source>
        <translation type="unfinished">Хэтэвч:</translation>
    </message>
    <message>
        <source>Network activity disabled.</source>
        <extracomment>A substring of the tooltip.</extracomment>
        <translation type="unfinished">Сүлжээний үйл ажиллагааг идэвхгүй болгосон.</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation type="unfinished">Түрүйвчийг цоожлох нууц үгийг солих</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation type="unfinished">&amp;Илгээх
 </translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation type="unfinished">&amp;Хүлээж авах</translation>
    </message>
    <message>
        <source>&amp;Verify message…</source>
        <translation type="unfinished">&amp;Баталгаажуулах мэссэж</translation>
    </message>
    <message>
        <source>Close Wallet…</source>
        <translation type="unfinished">Хэтэвч хаах…</translation>
    </message>
    <message>
        <source>Create Wallet…</source>
        <translation type="unfinished">Хэтэвч үүсгэх…</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation type="unfinished">&amp;Файл</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation type="unfinished">&amp;Тохиргоо</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation type="unfinished">&amp;Тусламж</translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">Алдаа</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation type="unfinished">Анхааруулга</translation>
    </message>
    <message>
        <source>Information</source>
        <translation type="unfinished">Мэдээллэл</translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation type="unfinished">Шинэчлэгдсэн</translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to Bitcoin network.</source>
        <extracomment>A substring of the tooltip.</extracomment>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation type="unfinished">Алдаа: %1</translation>
    </message>
    <message>
        <source>Warning: %1</source>
        <translation type="unfinished">Анхааруулга:%1</translation>
    </message>
    <message>
        <source>Date: %1
</source>
        <translation type="unfinished">Огноо:%1
</translation>
    </message>
    <message>
        <source>Amount: %1
</source>
        <translation type="unfinished">Дүн: %1
</translation>
    </message>
    <message>
        <source>Wallet: %1
</source>
        <translation type="unfinished">Түрийвч: %1
</translation>
    </message>
    <message>
        <source>Type: %1
</source>
        <translation type="unfinished">Төрөл: %1
</translation>
    </message>
    <message>
        <source>Label: %1
</source>
        <translation type="unfinished">Шошго: %1
</translation>
    </message>
    <message>
        <source>Address: %1
</source>
        <translation type="unfinished">Хаяг: %1
</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation type="unfinished">Гадагшаа гүйлгээ</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation type="unfinished">Дотогшоо гүйлгээ</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;unlocked&lt;/b&gt;</source>
        <translation type="unfinished">Түрүйвч &lt;b&gt;цоожтой&lt;/b&gt; ба одоогоор цоож &lt;b&gt;онгорхой&lt;/b&gt; байна</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
        <translation type="unfinished">Түрүйвч &lt;b&gt;цоожтой&lt;/b&gt; ба одоогоор цоож &lt;b&gt;хаалттай&lt;/b&gt; байна</translation>
    </message>
    <message>
        <source>Original message:</source>
        <translation type="unfinished">Эх зурвас:</translation>
    </message>
</context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Amount:</source>
        <translation type="unfinished">Хэмжээ:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation type="unfinished">Тѳлбѳр:</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation type="unfinished">Хэмжээ</translation>
    </message>
    <message>
        <source>Date</source>
        <translation type="unfinished">Огноо</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation type="unfinished">Баталгаажлаа</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation type="unfinished">Хэмжээг санах</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation type="unfinished">Ѳѳрчлѳлтийг санах</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(шошгогүй)</translation>
    </message>
    <message>
        <source>(change)</source>
        <translation type="unfinished">(ѳѳрчлѳх)</translation>
    </message>
</context>
<context>
    <name>CreateWalletDialog</name>
    <message>
        <source>Wallet</source>
        <translation type="unfinished">Түрүйвч</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation type="unfinished">Хаягийг ѳѳрчлѳх</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation type="unfinished">&amp;Шошго</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation type="unfinished">&amp;Хаяг</translation>
    </message>
    <message>
        <source>New sending address</source>
        <translation type="unfinished">Шинэ явуулах хаяг</translation>
    </message>
    <message>
        <source>Edit receiving address</source>
        <translation type="unfinished">Хүлээн авах хаягийг ѳѳрчлѳх</translation>
    </message>
    <message>
        <source>Edit sending address</source>
        <translation type="unfinished">Явуулах хаягийг ѳѳрчлѳх</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation type="unfinished">Түрүйвчийн цоожийг тайлж чадсангүй</translation>
    </message>
    <message>
        <source>New key generation failed.</source>
        <translation type="unfinished">Шинэ түлхүүр амжилттай гарсангүй</translation>
    </message>
</context>
<context>
    <name>Intro</name>
    <message>
        <source>Bitcoin</source>
        <translation type="unfinished">Биткойн</translation>
    </message>
    <message numerus="yes">
        <source>%n GB of space available</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(of %n GB needed)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(%n GB needed for full chain)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(sufficient to restore backups %n day(s) old)</source>
        <extracomment>Explanatory text on the capability of the current prune target.</extracomment>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">Алдаа</translation>
    </message>
    </context>
<context>
    <name>HelpMessageDialog</name>
    <message>
        <source>version</source>
        <translation type="unfinished">хувилбар</translation>
    </message>
    </context>
<context>
    <name>ShutdownWindow</name>
    <message>
        <source>Do not shut down the computer until this window disappears.</source>
        <translation type="unfinished">Энэ цонхыг хаагдтал компьютерээ бүү унтраагаарай</translation>
    </message>
</context>
<context>
    <name>ModalOverlay</name>
    <message>
        <source>Last block time</source>
        <translation type="unfinished">Сүүлийн блокийн хугацаа</translation>
    </message>
    </context>
<context>
    <name>OpenURIDialog</name>
    <message>
        <source>Paste address from clipboard</source>
        <extracomment>Tooltip text for button that allows you to paste an address that is in your clipboard.</extracomment>
        <translation type="unfinished">Копидсон хаягийг буулгах</translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation type="unfinished">Сонголтууд</translation>
    </message>
    <message>
        <source>IP address of the proxy (e.g. IPv4: 127.0.0.1 / IPv6: ::1)</source>
        <translation type="unfinished">проксигийн IP хаяг (жишээ нь: IPv4: 127.0.0.1 / IPv6: ::1)</translation>
    </message>
    <message>
        <source>&amp;Network</source>
        <translation type="unfinished">Сүлжээ</translation>
    </message>
    <message>
        <source>W&amp;allet</source>
        <translation type="unfinished">Түрүйвч</translation>
    </message>
    <message>
        <source>Client restart required to activate changes.</source>
        <extracomment>Text explaining that the settings changed will not come into effect until the client is restarted.</extracomment>
        <translation type="unfinished">Ѳѳрчлѳлтүүдийг идэвхижүүлхийн тулд клиентийг ахин эхлүүлэх шаардлагтай</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">Алдаа</translation>
    </message>
    <message>
        <source>This change would require a client restart.</source>
        <translation type="unfinished">Энэ ѳѳрчлѳлтийг оруулахын тулд кли1нт програмыг ахин эхлүүлэх шаардлагтай</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Available:</source>
        <translation type="unfinished">Хэрэглэж болох хэмжээ:</translation>
    </message>
    </context>
<context>
    <name>PSBTOperationsDialog</name>
    <message>
        <source>or</source>
        <translation type="unfinished">эсвэл</translation>
    </message>
    </context>
<context>
    <name>PeerTableModel</name>
    <message>
        <source>Address</source>
        <extracomment>Title of Peers Table column which contains the IP/Onion/I2P address of the connected peer.</extracomment>
        <translation type="unfinished">Хаяг</translation>
    </message>
    <message>
        <source>Type</source>
        <extracomment>Title of Peers Table column which describes the type of peer connection. The "type" describes why the connection exists.</extracomment>
        <translation type="unfinished">Тѳрѳл</translation>
    </message>
    <message>
        <source>Network</source>
        <extracomment>Title of Peers Table column which states the network the peer connected through.</extracomment>
        <translation type="unfinished">Сүлжээ</translation>
    </message>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>N/A</source>
        <translation type="unfinished">Алга Байна</translation>
    </message>
    <message>
        <source>Client version</source>
        <translation type="unfinished">Клиентийн хувилбар</translation>
    </message>
    <message>
        <source>&amp;Information</source>
        <translation type="unfinished">&amp;Мэдээллэл</translation>
    </message>
    <message>
        <source>General</source>
        <translation type="unfinished">Ерѳнхий</translation>
    </message>
    <message>
        <source>Network</source>
        <translation type="unfinished">Сүлжээ</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished">Нэр</translation>
    </message>
    <message>
        <source>Number of connections</source>
        <translation type="unfinished">Холболтын тоо</translation>
    </message>
    <message>
        <source>Block chain</source>
        <translation type="unfinished">Блокийн цуваа</translation>
    </message>
    <message>
        <source>Last block time</source>
        <translation type="unfinished">Сүүлийн блокийн хугацаа</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation type="unfinished">&amp;Нээх</translation>
    </message>
    <message>
        <source>&amp;Console</source>
        <translation type="unfinished">&amp;Консол</translation>
    </message>
    <message>
        <source>Clear console</source>
        <translation type="unfinished">Консолыг цэвэрлэх</translation>
    </message>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    <message>
        <source>&amp;Amount:</source>
        <translation type="unfinished">Хэмжээ:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation type="unfinished">&amp;Шошго:</translation>
    </message>
    <message>
        <source>&amp;Message:</source>
        <translation type="unfinished">Зурвас:</translation>
    </message>
    <message>
        <source>Show</source>
        <translation type="unfinished">Харуул</translation>
    </message>
    <message>
        <source>Remove the selected entries from the list</source>
        <translation type="unfinished">Сонгогдсон ѳгѳгдлүүдийг устгах</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="unfinished">Устгах</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation type="unfinished">Түрүйвчийн цоожийг тайлж чадсангүй</translation>
    </message>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Amount:</source>
        <translation type="unfinished">Хэмжээ:</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation type="unfinished">Зурвас:</translation>
    </message>
    <message>
        <source>Wallet:</source>
        <translation type="unfinished">Хэтэвч:</translation>
    </message>
    <message>
        <source>Copy &amp;Address</source>
        <translation type="unfinished">Хаягийг &amp;Хуулбарлах</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Date</source>
        <translation type="unfinished">Огноо</translation>
    </message>
    <message>
        <source>Label</source>
        <translation type="unfinished">Шошго</translation>
    </message>
    <message>
        <source>Message</source>
        <translation type="unfinished">Зурвас</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(шошгогүй)</translation>
    </message>
    <message>
        <source>(no message)</source>
        <translation type="unfinished">(зурвас алга)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Send Coins</source>
        <translation type="unfinished">Зоос явуулах</translation>
    </message>
    <message>
        <source>automatically selected</source>
        <translation type="unfinished">автоматаар сонгогдсон</translation>
    </message>
    <message>
        <source>Insufficient funds!</source>
        <translation type="unfinished">Таны дансны үлдэгдэл хүрэлцэхгүй байна!</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation type="unfinished">Хэмжээ:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation type="unfinished">Тѳлбѳр:</translation>
    </message>
    <message>
        <source>Send to multiple recipients at once</source>
        <translation type="unfinished">Нэгэн зэрэг олон хүлээн авагчруу явуулах</translation>
    </message>
    <message>
        <source>Add &amp;Recipient</source>
        <translation type="unfinished">&amp;Хүлээн авагчийг Нэмэх</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation type="unfinished">&amp;Бүгдийг Цэвэрлэ</translation>
    </message>
    <message>
        <source>Balance:</source>
        <translation type="unfinished">Баланс:</translation>
    </message>
    <message>
        <source>Confirm the send action</source>
        <translation type="unfinished">Явуулах үйлдлийг баталгаажуулна уу</translation>
    </message>
    <message>
        <source>S&amp;end</source>
        <translation type="unfinished">Яв&amp;уул</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation type="unfinished">Хэмжээг санах</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation type="unfinished">Ѳѳрчлѳлтийг санах</translation>
    </message>
    <message>
        <source>or</source>
        <translation type="unfinished">эсвэл</translation>
    </message>
    <message>
        <source>Confirm send coins</source>
        <translation type="unfinished">Зоос явуулахыг баталгаажуулна уу</translation>
    </message>
    <message>
        <source>The amount to pay must be larger than 0.</source>
        <translation type="unfinished">Тѳлѳх хэмжээ 0.-оос их байх ёстой</translation>
    </message>
    <message>
        <source>The amount exceeds your balance.</source>
        <translation type="unfinished">Энэ хэмжээ таны балансаас хэтэрсэн байна.</translation>
    </message>
    <message>
        <source>The total exceeds your balance when the %1 transaction fee is included.</source>
        <translation type="unfinished">Гүйлгээний тѳлбѳр %1-ийг тооцхоор нийт дүн нь таны балансаас хэтрээд байна.</translation>
    </message>
    <message numerus="yes">
        <source>Estimated to begin confirmation within %n block(s).</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Warning: Invalid Bitcoin address</source>
        <translation type="unfinished">Анхаар:Буруу Биткойны хаяг байна</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(шошгогүй)</translation>
    </message>
</context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>A&amp;mount:</source>
        <translation type="unfinished">Дүн:</translation>
    </message>
    <message>
        <source>Pay &amp;To:</source>
        <translation type="unfinished">Тѳлѳх &amp;хаяг:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation type="unfinished">&amp;Шошго:</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation type="unfinished">Копидсон хаягийг буулгах</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation type="unfinished">Зурвас:</translation>
    </message>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>Paste address from clipboard</source>
        <translation type="unfinished">Копидсон хаягийг буулгах</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation type="unfinished">&amp;Бүгдийг Цэвэрлэ</translation>
    </message>
    </context>
<context>
    <name>TransactionDesc</name>
    <message>
        <source>%1/unconfirmed</source>
        <extracomment>Text explaining the current status of a transaction, shown in the status field of the details window for this transaction. This status represents a transaction confirmed in at least one block, but less than 6 blocks.</extracomment>
        <translation type="unfinished">%1/баталгаажаагүй</translation>
    </message>
    <message>
        <source>%1 confirmations</source>
        <extracomment>Text explaining the current status of a transaction, shown in the status field of the details window for this transaction. This status represents a transaction confirmed in 6 or more blocks.</extracomment>
        <translation type="unfinished">%1 баталгаажилтууд</translation>
    </message>
    <message>
        <source>Date</source>
        <translation type="unfinished">Огноо</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation type="unfinished">үл мэдэгдэх</translation>
    </message>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Message</source>
        <translation type="unfinished">Зурвас</translation>
    </message>
    <message>
        <source>Transaction ID</source>
        <translation type="unfinished">Тодорхойлолт</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation type="unfinished">Хэмжээ</translation>
    </message>
    </context>
<context>
    <name>TransactionDescDialog</name>
    <message>
        <source>This pane shows a detailed description of the transaction</source>
        <translation type="unfinished">Гүйлгээний дэлгэрэнгүйг энэ бичил цонх харуулж байна</translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation type="unfinished">Огноо</translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="unfinished">Тѳрѳл</translation>
    </message>
    <message>
        <source>Label</source>
        <translation type="unfinished">Шошго</translation>
    </message>
    <message>
        <source>Unconfirmed</source>
        <translation type="unfinished">Баталгаажаагүй</translation>
    </message>
    <message>
        <source>Confirmed (%1 confirmations)</source>
        <translation type="unfinished">Баталгаажлаа (%1 баталгаажилт)</translation>
    </message>
    <message>
        <source>Conflicted</source>
        <translation type="unfinished">Зѳрчилдлѳѳ</translation>
    </message>
    <message>
        <source>Generated but not accepted</source>
        <translation type="unfinished">Үүсгэгдсэн гэхдээ хүлээн авагдаагүй</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation type="unfinished">Хүлээн авсан хаяг</translation>
    </message>
    <message>
        <source>Received from</source>
        <translation type="unfinished">Хүлээн авагдсан хаяг</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation type="unfinished">Явуулсан хаяг</translation>
    </message>
    <message>
        <source>Payment to yourself</source>
        <translation type="unfinished">Ѳѳрлүүгээ хийсэн тѳлбѳр</translation>
    </message>
    <message>
        <source>Mined</source>
        <translation type="unfinished">Олборлогдсон</translation>
    </message>
    <message>
        <source>(n/a)</source>
        <translation type="unfinished">(алга байна)</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(шошгогүй)</translation>
    </message>
    <message>
        <source>Transaction status. Hover over this field to show number of confirmations.</source>
        <translation type="unfinished">Гүйлгээний байдал. Энд хулганыг авчирч баталгаажуулалтын тоог харна уу.</translation>
    </message>
    <message>
        <source>Date and time that the transaction was received.</source>
        <translation type="unfinished">Гүйлгээг хүлээн авсан огноо ба цаг.</translation>
    </message>
    <message>
        <source>Type of transaction.</source>
        <translation type="unfinished">Гүйлгээний тѳрѳл</translation>
    </message>
    <message>
        <source>Amount removed from or added to balance.</source>
        <translation type="unfinished">Балансаас авагдсан болон нэмэгдсэн хэмжээ.</translation>
    </message>
</context>
<context>
    <name>TransactionView</name>
    <message>
        <source>All</source>
        <translation type="unfinished">Бүгд</translation>
    </message>
    <message>
        <source>Today</source>
        <translation type="unfinished">Ѳнѳѳдѳр</translation>
    </message>
    <message>
        <source>This week</source>
        <translation type="unfinished">Энэ долоо хоног</translation>
    </message>
    <message>
        <source>This month</source>
        <translation type="unfinished">Энэ сар</translation>
    </message>
    <message>
        <source>Last month</source>
        <translation type="unfinished">Ѳнгѳрсѳн сар</translation>
    </message>
    <message>
        <source>This year</source>
        <translation type="unfinished">Энэ жил</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation type="unfinished">Хүлээн авсан хаяг</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation type="unfinished">Явуулсан хаяг</translation>
    </message>
    <message>
        <source>To yourself</source>
        <translation type="unfinished">Ѳѳрлүүгээ</translation>
    </message>
    <message>
        <source>Mined</source>
        <translation type="unfinished">Олборлогдсон</translation>
    </message>
    <message>
        <source>Other</source>
        <translation type="unfinished">Бусад</translation>
    </message>
    <message>
        <source>Min amount</source>
        <translation type="unfinished">Хамгийн бага хэмжээ</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation type="unfinished">Баталгаажлаа</translation>
    </message>
    <message>
        <source>Date</source>
        <translation type="unfinished">Огноо</translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="unfinished">Тѳрѳл</translation>
    </message>
    <message>
        <source>Label</source>
        <translation type="unfinished">Шошго</translation>
    </message>
    <message>
        <source>Address</source>
        <translation type="unfinished">Хаяг</translation>
    </message>
    <message>
        <source>ID</source>
        <translation type="unfinished">Тодорхойлолт</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation type="unfinished">Экспорт амжилтгүй боллоо</translation>
    </message>
    <message>
        <source>The transaction history was successfully saved to %1.</source>
        <translation type="unfinished">Гүйлгээнүй түүхийг %1-д амжилттай хадгаллаа.</translation>
    </message>
    <message>
        <source>to</source>
        <translation type="unfinished">-рүү/руу</translation>
    </message>
</context>
<context>
    <name>WalletFrame</name>
    <message>
        <source>Create a new wallet</source>
        <translation type="unfinished">Шинэ түрийвч үүсгэх</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">Алдаа</translation>
    </message>
    </context>
<context>
    <name>WalletModel</name>
    <message>
        <source>Send Coins</source>
        <translation type="unfinished">Зоос явуулах</translation>
    </message>
    </context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation type="unfinished">&amp;Экспорт</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation type="unfinished">Сонгогдсон таб дээрхи дата-г экспортлох</translation>
    </message>
    </context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Done loading</source>
        <translation type="unfinished">Ачааллаж дууслаа</translation>
    </message>
    <message>
        <source>Insufficient funds</source>
        <translation type="unfinished">Таны дансны үлдэгдэл хүрэлцэхгүй байна</translation>
    </message>
    </context>
</TS>